@@ -4,7 +4,7 @@ use warnings;
 use utf8;
 use App::bif::Context;
 
-our $VERSION = '0.1.0_22';
+our $VERSION = '0.1.0_23';
 
 sub run {
     my $ctx = App::bif::Context->new(shift);
@@ -82,14 +82,11 @@ sub run {
         }
     }
 
-    if ($i) {
-        $ctx->start_pager($i);
+    $ctx->start_pager;
 
-        require Term::Size;
-        print $table->render( ( Term::Size::chars() )[0] );
+    print $table->render($App::bif::Context::term_width);
 
-        $ctx->end_pager;
-    }
+    $ctx->end_pager;
 
     $ctx->ok( 'ListIssues', \@projects );
 }
@@ -103,7 +100,7 @@ bif-list-issues - list projects' issues
 
 =head1 VERSION
 
-0.1.0_22 (2014-05-10)
+0.1.0_23 (2014-06-04)
 
 =head1 SYNOPSIS
 
