@@ -4,7 +4,7 @@ use warnings;
 use App::bif::Context;
 use IO::Prompt::Tiny qw/prompt/;
 
-our $VERSION = '0.1.0_22';
+our $VERSION = '0.1.0_23';
 
 sub run {
     my $ctx = App::bif::Context->new(shift);
@@ -61,14 +61,6 @@ sub run {
             $ctx->{id}        = $db->nextval('topics');
             $ctx->{update_id} = $db->nextval('updates');
 
-            $ctx->update_repo(
-                {
-                    ruid    => $ruid,
-                    message => "new issue $ctx->{id} [$pinfo->{path}]",
-                    related_update_id => $ctx->{update_id},
-                }
-            );
-
             $db->xdo(
                 insert_into => 'updates',
                 values      => {
@@ -94,6 +86,13 @@ sub run {
                 values      => { merge => 1 },
             );
 
+            $ctx->update_repo(
+                {
+                    id      => $ruid,
+                    message => "new issue $ctx->{id} [$pinfo->{path}]",
+                    related_update_id => $ctx->{update_id},
+                }
+            );
         }
     );
 
@@ -110,7 +109,7 @@ bif-new-issue - add a new issue to a project
 
 =head1 VERSION
 
-0.1.0_22 (2014-05-10)
+0.1.0_23 (2014-06-04)
 
 =head1 SYNOPSIS
 
